<h2 align="center"> Lichess: A Python wrapper for the Lichess API</h2>
<p align="center">
<img src="https://img.shields.io/pypi/l/lichess?label=license" alt="License"/>
<a href="https://pypi.org/project/lichess/"><img alt="PyPI" src="https://img.shields.io/pypi/v/lichess"></a>
<img src="https://img.shields.io/github/repo-size/qe/lichess?label=repo size" alt="GitHub Repo Size"/>
<img src="https://img.shields.io/github/languages/code-size/qe/lichess?label=code size" alt="GitHub Code Size (bytes)"/>
<img src="https://img.shields.io/tokei/lines/github/qe/lichess?label=lines of code" alt="Total Lines of Code"/>
</p>

<p align="center">
  <a href="https://github.com/qe/lichess/archive/refs/heads/master.zip">Download</a>
  ·
  <a href="https://github.com/qe/lichess/issues/new?template=bug_report.md">Report bug</a>
  <br>
  <br>
</p>
